From f7ace410d12b515d72862078fa8b01a1354c18db Mon Sep 17 00:00:00 2001
From: Gregory Nutt
Date: Tue, 3 Feb 2015 17:01:48 -0600
Subject: [PATCH] Minor updates to comments, debug messages, documentation
---
Documentation/NuttX.html | 10 +++++++++-
net/icmpv6/icmpv6_rsolicit.c | 6 +++---
2 files changed, 12 insertions(+), 4 deletions(-)
diff --git a/Documentation/NuttX.html b/Documentation/NuttX.html
index 0a4e80bcff..0e6db16b51 100644
--- a/Documentation/NuttX.html
+++ b/Documentation/NuttX.html
@@ -8,7 +8,7 @@
NuttX RTOS
- Last Updated: February 2, 2014
+ Last Updated: February 3, 2014
|
@@ -755,6 +755,14 @@
+
+
|
+
+
+ ICMPv6 autonomous auto-configuration
+
+ |
+
|
diff --git a/net/icmpv6/icmpv6_rsolicit.c b/net/icmpv6/icmpv6_rsolicit.c
index 132c3e0fc0..17a28e66b1 100644
--- a/net/icmpv6/icmpv6_rsolicit.c
+++ b/net/icmpv6/icmpv6_rsolicit.c
@@ -120,7 +120,7 @@ void icmpv6_rsolicit(FAR struct net_driver_s *dev)
net_ipv6addr_copy(icmp->srcipaddr, dev->d_ipv6addr);
/* Set up the ICMPv6 Neighbor Solicitation message */
sol = ICMPv6RSOLICIT;
sol->type = ICMPV6_ROUTER_SOLICIT; /* Message type */
@@ -163,7 +163,7 @@ void icmpv6_rsolicit(FAR struct net_driver_s *dev)
* to the Ethernet MAC address 33:33:00:01:00:03.
*
* NOTES: This appears correct for the ICMPv6 Router Solicitation
* Message, but the ICMPv6 Neighbor Solicitation message seems to
* use 33:33:ff:01:00:03.
*/
@@ -206,7 +206,7 @@ void icmpv6_rsolicit(FAR struct net_driver_s *dev)
/* SLIP has no link layer header */
#endif
- nllvdbg("Outgoing ICMPv6 Neighbor Solicitation length: %d (%d)\n",
+ nllvdbg("Outgoing ICMPv6 Router Solicitation length: %d (%d)\n",
dev->d_len, (icmp->len[0] << 8) | icmp->len[1]);
#ifdef CONFIG_NET_STATISTICS
|
@@ -120,7 +120,7 @@ void icmpv6_rsolicit(FAR struct net_driver_s *dev)
net_ipv6addr_copy(icmp->srcipaddr, dev->d_ipv6addr);
- /* Set up the ICMPv6 Neighbor Solicitation message */
+ /* Set up the ICMPv6 Router Solicitation message */
sol = ICMPv6RSOLICIT;
sol->type = ICMPV6_ROUTER_SOLICIT; /* Message type */
@@ -163,7 +163,7 @@ void icmpv6_rsolicit(FAR struct net_driver_s *dev)
*
* NOTES: This appears correct for the ICMPv6 Router Solicitation
- * Message, but the ICMPv6 Neighbor Solicitation message seems to
+ * Message, but the ICMPv6 Router Solicitation message seems to
* use 33:33:ff:01:00:03.
*/